import { NextFunction, Request, Response } from "express";
import { CreateJwtTokenRequest, UserType } from "../models/user.modal";
import { createJWTToken, createUserToken } from "../services/user.service";
import { TypedRequestBody } from "../type/api";
import { checkBodyAndThrowError } from "../utils/checkBodyAndThrowError";
import { successResponse } from "../utils/response";

export const getUserTokenController = async (
  req: Request,
  res: Response,
  next: NextFunction
) => {
  try {
    const token = req.headers.authorization?.split(" ")[1];
    const { companyName } = req.params;

    if (!token) throw new Error("401:Token is required");
    if (!companyName) throw new Error("400:companyName is required");

    const user = await createUserToken(token, companyName);
    successResponse<UserType>(res, user);
  } catch (error) {
    next(error);
  }
};

export const createJwtTokenController = async (
  req: TypedRequestBody<CreateJwtTokenRequest>,
  res: Response,
  next: NextFunction
) => {
  try {
    checkBodyAndThrowError(req.body, [
      "name",
      "amount",
      "lobby",
      "companyName",
    ]);

    const token = await createJWTToken(req.body);
    successResponse<string>(res, token);
  } catch (error) {
    next(error);
  }
};
