import { v4 as uuidv4 } from "uuid";
import Company, { CompanyOptions } from "../models/company.modal";

export const createCompany = async (name: string) => {
  try {
    const existingCompanyName = await getCompanyByOptions({ name });
    if (existingCompanyName) throw "409:Company already exists";

    const secretKey = uuidv4();

    const existingCompanySecretKey = await getCompanyByOptions({ secretKey });
    if (existingCompanySecretKey) throw "409:Company secret key already exists";

    const newCompany = await Company.create({
      name,
      secretKey,
    });

    return newCompany;
  } catch (error) {
    throw new Error((error as string) || "500:Failed to create company");
  }
};

export const getCompanyById = async (id: string) => {
  try {
    const company = await Company.findById(id);
    return company;
  } catch (error) {
    throw new Error(
      ((error as string) || "500:Failed to get company by") + `id: ${id}`
    );
  }
};

export const getCompanyByOptions = async (options: CompanyOptions) => {
  try {
    const company = await Company.findOne(options);
    return company;
  } catch (error) {
    throw new Error(
      ((error as string) || "500:Failed to get company by") +
        `options: ${JSON.stringify(options)}`
    );
  }
};
