import jwt from "jsonwebtoken";
import { UserPayload, UserPayloadRequest } from "../models/user.modal";

export const verifyToken = (token: string, secret: string) => {
  try {
    const decoded = jwt.verify(token, secret);
    if (!decoded) throw "401:Invalid token";

    return decoded as UserPayload;
  } catch (error) {
    if (error instanceof jwt.TokenExpiredError) {
      throw new Error("401:Token expired");
    }
    throw new Error((error as string) || "500:Failed to verify token");
  }
};

export const generateToken = (payload: UserPayloadRequest, secret: string) => {
  try {
    const token = jwt.sign(payload, secret, { expiresIn: "1h" });
    return token;
  } catch (error) {
    throw new Error((error as string) || "500:Failed to generate token");
  }
};
